======================
82.0 Avengers: Endgame
======================

The Avocado team is proud to present another release: Avocado 82.0,
AKA "Avengers: Endgame", is now available!

This release is also an :ref:`LTS<rfc-long-term-stability>` Release,
with a different :ref:`Release Notes<lts_82_0>` that covers the
changes since :ref:`69.x LTS<lts_69_0>`.

Release documentation: `Avocado 82.0
<http://avocado-framework.readthedocs.io/en/82.0/>`_

Bug Fixes
=========

* Avocado can now find tests on classes that are imported using
  relative ``import`` statements with multiple classes.  Previously
  only the first class imported in such a statement was properly
  processed.

* ``avocado run`` will now create test suites without an automatic
  (and usually very verbose) name, but instead without a name, given
  that there will be only one suite on such jobs.  This restores
  the ``avocado run`` behavior users expected and are used to.

* Hint files are now being respected again, this time within the
  context of test suite creation.

* Filtering by tags is now working properly when using the resolver,
  that is, when using ``avocado list --resolver -t $tag --
  $reference``.

* Test suites now properly respect the configuration given to them, as
  opposed to using a configuration composed by the default registered
  option values.

* Fixed the "elapsed time" produced by the ``avocado-instrumented``
  nrunner runner (that is, ``avocado-runner-avocado-instrumented``).

* ``avocado --verbose list --resolver -- $reference`` has reinstated
  the presentation of failed resolution information, which is useful
  for understanding why a test reference was not resolved into a test.

* The "legacy replay plugin", that is, ``avocado run --replay``, can
  now replay a subset of tests based on their status.

* The ``avocado diff`` command won't crash anymore if given
  ``sysinfo`` files with binary content.  It will log the issue, and
  not attempt to present binary differences.

* The HTML report generated by ``avocado diff`` now runs properly
  and won't crash.

* The asset fetcher plugin won't crash anymore due to differences in
  the AST based node attributes.

* :class:`avocado.utils.process.FDDrainer` now properly respects the
  presence and absence of newlines produced when running new processes
  via :func:`avocado.utils.process.run` and friends.  This also fixes
  tests that relied on the "output check" feature because of missing
  newlines.

* The ``nrunner`` plugin will now always display test status in the
  most natural order, that is, ``STARTED`` before ``PASS`` or
  ``FAIL``.

* The ``nrunner`` plugin will now properly set the job status in case
  of test failures, resulting in the job (and ``avocado run``) exit
  status to properly signal failures.

* A vast documentation review was performed, with many fixes and
  improvements.

For more information, please check out the complete
`Avocado changelog
<https://github.com/avocado-framework/avocado/compare/81.0...82.0>`_.
